# -*- coding: UTF-8 -*-
import re
import json


def get_tags():
    return ['3', '3.2', '3.2.1', '3.2.1.5']


def run_task(runcontext):
    ansible_params = runcontext.get_mod_params_instance()
    runcontext.set_mod_params_instance(ansible_params, "chdir", None)
    runcontext.set_mod_params_instance(ansible_params, "executable", None)
    module = runcontext.get_module_file("shell.py")
    rc, out = run_audit(runcontext, ansible_params, module)
    return rc, out


def run_audit(runcontext, ansible_params, module):
    ret_code = -1
    curtemplate = runcontext.get_template()
    dockerbin = runcontext.get_extra_var('DOCKER_BIN')
    dockerbin = runcontext.replace_inject_characters(dockerbin)

    tmp_vars = {}
    tmp_vars["policyresult"] = "failed"
    tmp_vars["checkresult1"] = "failed"
    tmp_vars["checkvalue1"] = ''
    tmp_vars["scancommand1"] = "if [[ -e '%s' ]]; then auditctl -l | awk -F' ' '{print $2}' |grep '^%s$'; else echo 'docker not installed';fi" % (dockerbin, dockerbin)

    tmp_vars["checkresult2"] = "failed"
    tmp_vars["checkvalue2"] = ''
    tmp_vars["scancommand2"] = '''systemctl is-enabled auditd 2>/dev/null'''

    runcontext.set_mod_params_instance(ansible_params, "command", tmp_vars["scancommand1"])
    arc1, astdout1, astderr1 = runcontext.invoke_module(module, ansible_params)
    runcontext.sleep()

    runcontext.set_mod_params_instance(ansible_params, "command", tmp_vars["scancommand2"])
    arc2, astdout2, astderr2 = runcontext.invoke_module(module, ansible_params)
    runcontext.sleep()

    if arc1 != 0:
        return -2, "Failed to invoke module: %s." % astdout1
    resultjson1 = json.loads(astdout1)
    astdout1 = resultjson1["stdout"]
    astderr1 = resultjson1["stderr"]
    runcontext.log_debug_json(resultjson1)
    match1_found = re.match(".+", astdout1)
    if match1_found is None:
        tmp_vars["checkvalue1"] = astdout1
    else:
        tmp_vars["checkresult1"] = "pass"
        tmp_vars["checkvalue1"] = astdout1

    if arc2 != 0:
        return -2, "Failed to invoke module: %s." % astdout2
    resultjson2 = json.loads(astdout2)
    astdout2 = resultjson2["stdout"]
    astderr2 = resultjson2["stderr"]
    runcontext.log_debug_json(resultjson1)
    match2_found = re.match("enabled", astdout2)
    if match2_found is None:
        tmp_vars["checkvalue2"] = astdout2
    else:
        tmp_vars["checkresult2"] = "pass"
        tmp_vars["checkvalue2"] = astdout2

    if tmp_vars["checkresult1"] == "pass" and tmp_vars["checkresult2"] == "pass":
        tmp_vars["policyresult"] = "pass"
        ret_code = 0

    rc, out = curtemplate.render(runcontext.get_template_file('t_3_2_1_5.j2'), **tmp_vars)
    if rc is False:
        return -2, "Failed to render template.%s" % out
    return ret_code, out
